.. GsuiteToMd documentation master file, created by
   sphinx-quickstart on Sat Jan 23 14:42:23 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to GsuiteToMd's documentation!
======================================



GsuiteToMd is a  library built on top of `PyDrive`_ that offers a simple way to convert Documents store in Google Drive in markdown.

How to install
==============

You can install GsuiteToMd with regular ``pip`` command.

::

   $ pip install GsuiteToMd

.. toctree::
   :maxdepth: 2

   README
   gstomd

.. _`PyDrive`: https://github.com/gsuitedevs/PyDrive

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
